@@ -293,12 +293,20 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         :param message_id: Starting message id of published messages.
         :param messages: Collection of messages to publish.
         """
+        # return immediately when no messages to publish; otherwise, empty
+        # publish message is sent, rabbitmq streams broker sends no
+        # response and the publishing task waits forever
+        if not messages:
+            return
+
         task = self._loop.create_future()
         pm = SentMessages(task, message_id, message_id + len(messages) - 1)
         self._published_messages[publisher_id] = pm
 
         frame = self.encoder.encode_publish(publisher_id, message_id, *messages, amqp=amqp)
         self.send_frame(frame)
+
+        assert len(messages) > 0
         return await task
 
     @retry(ProtocolError, predicate=is_stream_na, retry_after=1)
