@@ -32,7 +32,7 @@ from rbfly.error import RbFlyError
 from rbfly.streams.client import Scheme, StreamsClient, streams_client, \
     connection
 from rbfly.streams._client import PublisherTrait, Publisher, PublisherBatch, \
-    PublisherBin, PublisherBinBatch
+    PublisherBatchMem, PublisherBin, PublisherBinBatch
 from rbfly.streams.offset import Offset, OffsetType
 from rbfly.streams.protocol import ProtocolError
 
@@ -182,6 +182,8 @@ async def test_publisher_send_amqp_batch() -> None:
     """
     Test publisher sending batch of AMQP message.
     """
+    # pylint: disable=protected-access
+
     client = mock.AsyncMock()
     protocol = await client.get_protocol()
 
@@ -197,6 +199,35 @@ async def test_publisher_send_amqp_batch() -> None:
     assert publisher.message_id == 13
     assert publisher._data == []
 
+@pytest.mark.asyncio
+async def test_publisher_send_mem_batch() -> None:
+    """
+    Test publisher sending batch of AMQP message with memory protection.
+    """
+    # pylint: disable=protected-access
+
+    client = mock.AsyncMock()
+    await client.get_protocol()
+
+    publisher = PublisherBatchMem(client, 'stream', 2, 'pub-name', 11)
+    await publisher.batch(b'12345', max_len=3)
+    await publisher.batch(b'54321', max_len=3)
+    await publisher.batch(b'54321', max_len=3)
+
+    # batch blocks due to max_len == 3
+    with pytest.raises(asyncio.TimeoutError) as ex_ctx:
+        await asyncio.wait_for(publisher.batch(b'54321', max_len=3), 0.1)
+
+    assert type(ex_ctx.value) == asyncio.TimeoutError
+
+    # data flushed...
+    await publisher.flush()
+    assert len(publisher._data) == 0
+
+    # ... so can batch again
+    await publisher.batch(b'54321', max_len=3)
+    assert len(publisher._data) == 1
+
 @pytest.mark.asyncio
 async def test_publisher_send_binary() -> None:
     """
@@ -217,6 +248,8 @@ async def test_publisher_send_batch_binary() -> None:
     """
     Test publisher sending batch of binary data.
     """
+    # pylint: disable=protected-access,unnecessary-lambda-assignmen
+
     client = mock.AsyncMock()
     protocol = await client.get_protocol()
 
@@ -245,7 +278,10 @@ def test_connection_coroutine() -> None:
     """
     Test if connection decorator returns coroutine function.
     """
-    async def f(): pass  # type: ignore
+    # pylint: disable=invalid-name
+
+    async def f() -> None:
+        pass
 
     assert inspect.iscoroutinefunction(connection(f))
     assert inspect.iscoroutinefunction(connection(partial(f)))
@@ -255,6 +291,8 @@ async def test_connection_async_iterator() -> None:
     """
     Test if connection decorator returns asynchronous iterator function.
     """
+    # pylint: disable=invalid-name,unused-argument
+
     async def fx(client: StreamsClient) -> AsyncIterator[int]:
         for i in range(10):
             yield i
@@ -274,6 +312,12 @@ async def test_connection_async_iterator() -> None:
 @pytest.mark.skip
 @pytest.mark.asyncio
 async def test_connection_async_generator_yield() -> None:
+    """
+    Test if connection decorator returns asynchronous generator function
+    which accepts data with `asend` method.
+    """
+    # pylint: disable=invalid-name,unused-argument
+
     @connection
     async def fx(client: StreamsClient, data: list[int]) -> AsyncGenerator[None, int]:
         while True:
@@ -287,11 +331,11 @@ async def test_connection_async_generator_yield() -> None:
     data: list[int] = []
 
     f = fx(client, data)
-    await f.asend(None)  # type: ignore
-    await f.asend(1)     # type: ignore
-    await f.asend(2)     # type: ignore
-    await f.asend(3)     # type: ignore
-    await f.aclose()     # type: ignore
+    await f.asend(None)
+    await f.asend(1)
+    await f.asend(2)
+    await f.asend(3)
+    await f.aclose()
 
     assert data == [1, 2, 3]
     client.disconnect.assert_called_once()
@@ -301,9 +345,13 @@ def test_connection_invalid() -> None:
     Test if error is raised by connection decorator for non-asynchronous
     function.
     """
-    def f(): pass  # type: ignore
+    # pylint: disable=invalid-name
+
+    def f() -> None:
+        pass
 
     with pytest.raises(RbFlyError):
-        connection(f)
+        # `f` is not valid function from type checks point of view as well
+        connection(f)  # type: ignore
 
 # vim: sw=4:et:ai
